diff --git a/core/tests/Drupal/Tests/PerformanceTestTrait.php b/core/tests/Drupal/Tests/PerformanceTestTrait.php
index ac6f589caa4ede86ef0ef9d05712951520577ab9..d7b780f3aa50b035fbd1cddc2d007ff19de2ecec 100644
--- a/core/tests/Drupal/Tests/PerformanceTestTrait.php
+++ b/core/tests/Drupal/Tests/PerformanceTestTrait.php
@@ -640,7 +640,7 @@ protected function assertMetrics(
     array $expected,
     PerformanceData $performance_data,
   ): void {
     // Allow those metrics to have a range of +/- 50 bytes, so small changes
     // are not significant enough to break tests.
     $assertRange = [
       'ScriptBytes',
@@ -648,7 +648,7 @@ protected function assertMetrics(
     ];
     foreach ($expected as $name => $metric) {
       if (in_array($name, $assertRange)) {
-        $this->assertCountBetween($metric - 50, $metric + 50, $performance_data->{"get$name"}(), "Asserting $name");
+        $this->assertCountBetween($metric - 500, $metric + 500, $performance_data->{"get$name"}(), "Asserting $name");
       }
       else {
         $this->assertSame($metric, $performance_data->{"get$name"}(), "Asserting $name");
@@ -640,7 +640,7 @@ protected function assertMetrics(
     PerformanceData $performance_data,
   ): void {
-    // Allow those metrics to have a range of +/- 50 bytes, so small changes
+    // Allow those metrics to have a range of +/- 500 bytes, so small changes
     // are not significant enough to break tests.
     $assertRange = [